# datastructures: Implementation of core datastructures for R.
#
# Copyright (C) Simon Dirmeier
#
# This file is part of datastructures.
#
# datastructures is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# datastructures is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with datastructures. If not, see <http://www.gnu.org/licenses/>.


context("deque")


ds <- c(queue, stack)


test_that("abstract class cannot get instantiated", {
    expect_error(methods::new("deque"))
})


test_that("deque clears correctly",
{
  for (d in ds)
  {
      deq <- d()
      deq <- insert(deq, rnorm(10))
      expect_equal(size(deq), 1)
      deq <- clear(deq)
      expect_equal(size(deq), 0)
  }
})
